!	*****************************
!	functions
!	*****************************
!	last modified:

!---error function													   
!   based on Chebyshev fitting, taken from Press et al.                
!   promoted to double precision                                       

real function erfcc(x)
     implicit none
	  real*8 t,z,x
      
	  z=dabs(x)
      t=1./(1.d0+0.5d0*z)
	  erfcc=t*dexp(-z*z-1.26551223d0+t*(1.00002368d0+t*(.37409196d0+t*(.09678418d0+t*(-.18628806d0+t*&
	  (.27886807d0+t*(-1.13520398d0+t*(1.48851587d0+t*(-.82215223d0+t*.17087277d0)))))))))
      if (x.lt.0.d0)then
		erfcc=2.d0-erfcc
	  endif
return
end


!_____O2 saturation concentration (Garcia and Gordon, 1992)
real function sol_O2(t, pA)
	implicit none
	

    real :: A1 = -58.3877
    real :: A2 = 85.8079
	real :: A3 = 23.8439

 
	real :: B1 =-0.034892
	real :: B2 =0.015568
	real :: B3 =-0.0019387

	real*8 beta, Ts, t, pH2OP, pA
	
	Ts=273.15+t
	beta=A1 +A2*100.0/Ts +A3*log(Ts/100.0)+ 35.0*(B1+ B2*(Ts/100.0)+ B3*(Ts/100.0)**2.0)					! bunsen coefficient
	pH2OP=1.0-exp(24.4543-67.4509*(100.0/Ts)-4.8489*log(Ts/100.0)-0.000544*35)								! correction to moist air
	sol_O2=exp(beta)/22.4136*pA*pH2OP*1d6
		
																											! saturation concentration
! Local declarations
!    real :: A0 = 2.00907
!    real :: A1 = 3.22014
!    real :: A2 = 4.05010
!    real :: A3 = 4.94457
!    real :: A4 = -0.256847 
!    real :: A5 = 3.88767
!    real :: B0 = -6.24523E-3
!	real :: B1 =-7.37614E-3
!	real :: B2 =-1.03410E-2
!	real :: B3 =-8.17083E-3
!	real :: C0 =-4.88682E-7
	
!	real*8 beta, Ts, t
!	
!	Ts=log( (298.15-t)/ (273.15+t))
!	beta=A0+ A1*Ts+ A2*Ts**2.0+ A3*Ts**3.0+ A4*Ts**4.0+ A5*Ts**5.0+ 35.0*(B0+ B1*Ts+ B2*Ts**2.0+ B3*Ts**3.0)+ C0*35.0**2
!	sol_O2=1000.0/22.3916*exp(beta)
	
return 
end


!_____CO2 saturation concentration (Garcia and Gordon, 1992)
real function sol_CO2(t, pA)
	implicit none
	
! Local declarations
    real :: A1 = -160.7333
    real :: A2 = 215.4152
    real :: A3 = 89.8920
    real :: A4 = -1.47759
    real :: B1 = 0.029941 
    real :: B2 = -0.027455
    real :: B3 = 0.0053407
	
	real*8 lnF, Ts, t, pH2OP, pA, AK0
	
	Ts=273.15+t
	!AK0=-58.0931+9050.69/Ts+22.2940*LOG(Ts/100.)&
	!+35.0*(0.027766-0.025888*Ts/100.+0.0050578*Ts*Ts/10000.)
	!AK0=EXP(AK0)*1.E+3
	!sol_CO2=280.E-6*AK0*1.E+3
	
	!BC=280.E-6*AK0*1.E+3
	
	lnF=A1 +A2*100.0/Ts +A3*log(Ts/100.0)+ A4*(Ts/100.0)**2.0+ 35.0*(B1+ B2*(Ts/100.0)+ B3*(Ts/100.0)**2.0) ! solubility function
	pH2OP=1.0-exp(24.4543-67.4509*(100.0/Ts)-4.8489*log(Ts/100.0)-0.000544*35)								! correction to moist air
	sol_CO2=exp(lnF)/pH2OP*pA*pH2OP*1d6																		! saturation concentration
return 
end

!_____Schmidt number for O2 (Wanninkhof, 1992)
real function sc_O2(t)
	implicit none
	
	real :: A=1638.0
	real :: B=81.83
	real :: C=1.483
	real :: D=0.008004
	
	real*8 t
	
	sc_O2=A- B*t +C*t**2- D*t**3
	
return 
end

!_____Schmidt number for CO2 (Wanninkhof, 1992)
real function sc_CO2(t)
	implicit none
	
	real :: A=2073.1
	real :: B=125.62
	real :: C=3.6276
	real :: D=0.043219
	
	real*8 t
	
	sc_CO2=A- B*t +C*t**2- D*t**3
	
return 
end

!_____Dissociation constant of CO2 (mmol m-3) (Dickson and Millero, 1987)
real function KK1(t,h)
	implicit none
	
	
	real*8 t, Ts, logK1, lnK1, R, p, deltaV
	real*8 deltaK, lnKP, rho, g, h
	
	rho=1025.0
	g=9.82
	Ts=273.15+t
	R=83.1465
	p=1.0+rho*g*h/10.0**5
	
	!logK1=-62.008+3670.7/Ts+9.7944*log(Ts)-0.0118*35.0+0.000116*35.0*35
	lnK1=2.83655-2307.1266/Ts-1.5529413*log(Ts)-(0.207608410+4.0484/Ts)*35.0**(0.5)+0.0846834*35.0&
	-0.00654208*35.0**(3.0/2.0)+log(1.0-0.001005*35.0)
	deltaV=-25.5 +0.127*t
	deltaK=(-3.08+0.0877*t)/1000.0
	lnKP=lnK1-deltaV/(R*Ts)*p+0.5*deltaK/(R*Ts)*p**2.0
	!lnKP=-2.303*logK1-deltaV/(R*Ts)*p+0.5*deltaK/(R*Ts)*p**2.0
	KK1=exp(lnKP)*1.0d6!10.0**(-logK1)*1.0d6!exp(lnKP)*1.0d6

return 
end


!_____Dissociation constant of CO2 (mmol m-3) (Dickson and Millero, 1987)
real function KK2(t, h)
	implicit none
	
	real*8 t, Ts, logK2, lnK2, R, p, deltaV
	real*8 deltaK, lnKP, rho, g, h, testKK2
	
	rho=1025.0
	g=9.82
	Ts=273.15+t
	R=83.1465
	p=1.0+rho*g*h/10.0**5
	
	!logK2=4.777+1394.7/Ts-0.0184*35.0+ 0.000118*35.0**2.0
	lnK2=-9.226508-3351.6106/Ts-0.2005743*log(Ts)-(0.106901773+23.9722/Ts)*35.0**(0.5)+0.1130822*35.0&
	-0.00846934*35.0**(3.0/2.0)+log(1-0.001005*35.0)							! Roy et al., 1993
	deltaV=-15.8 -0.0219*t
	deltaK=(-1.13-0.147*t)/1000.0
	lnKP=lnK2-deltaV/(R*Ts)*p+0.5*deltaK/(R*Ts)*p**2.0
	!lnKP=-2.303*logK2-deltaV/(R*Ts)*p+0.5*deltaK/(R*Ts)*p**2.0
	KK2=exp(lnKP)*1.0d6!10.0**(-logK2)*1.0d6!exp(lnKP)*1.0d6
	
return 
end

!_____Dissociation constant of H20 (mmol m-3) (Millero, 1995)
real function KK3(t, h)
	implicit none
	
	
	real*8 t, Ts, lnK3, R, p, deltaV
	real*8 deltaK, lnKP, rho, g, h
	
	rho=1025.0
	g=9.82
	Ts=273.15+t
	R=83.1465
	p=1.0+rho*g*h/10.0**5

	
	lnK3=148.96502-13847.26/Ts-23.6521*log(Ts)+ 35.0**(0.5)*(-5.977+118.67/Ts+1.0495*log(Ts))-0.01615*35.0
	deltaV=-20.0 +0.112*t-0.00141*t**2.0
	deltaK=(-5.13+0.0749*t)/1000.10
	lnKP=lnK3-deltaV/(R*Ts)*p+0.5*deltaK/(R*Ts)*p**2.0
	KK3=exp(lnKP)*1.0d6
return 
end


!_____Dissociation constant of sulfide (mmol m-3) (Dickson, 1990)
real function KK4(t, h)
	implicit none
	
	
	real*8 t, Ts, logK4, h
	Ts=273.15+t
	
	logK4=2.527 + 1359.96 /Ts - 0.206 * 35.0**(1.0/3.0)
	KK4	 =10.0**(-logK4)*1.0d6
	
return 
end



!_____Dissociation constant of boron (mmol m-3) (Dickson, 1990)
real function KK5(t, h)
	implicit none
	
	real*8 t, Ts, lnK5, R, p, deltaV
	real*8 deltaK, lnKP, rho, g, h, testKK5
	
	rho=1025.0
	g=9.82
	Ts=273.15+t
	R=83.1465
	p=1.0+rho*g*h/10.0**5
		
	lnK5=148.0248+137.1942*35.0**(0.5)+1.62142*35.0&
		+1.0/Ts*(-8966.9-2890.53*35.0**0.5-77.942*35.0+1.728*35.0**(1.5)-0.0996*35.0**2.0)&
		+log(Ts)*(-24.4344-25.085*35.0**0.5-0.2474*35.0)+0.053105*35.0**0.5*Ts
	deltaV=-28.6 +0.112*t-0.000321*t**2.0
	deltaK=(-3.0+0.0427*t)/1000.10
	lnKP=lnK5-deltaV/(R*Ts)*p+0.5*deltaK/(R*Ts)*p**2.0
	KK5=exp(lnKP)*1.0d6

return 
end

!_____Solubility product of calcite (mmol m-3)^2 (Mucci, 1983 and Millero, 1983)
real function KKca(t,h)
	implicit none
	
	real*8 t, Ts, lnKKca, R, p, deltaV, deltaK, lnKP, rho, g, h

	rho=1025.0
	g=9.82
	
	Ts=273.15+t
	R=83.1465
	p=1.0+rho*g*h/10.0**5
	
	lnKKca=-395.8293+6537.773/Ts+71.595*log(Ts)-0.17959*Ts+(-1.78938+410.64/Ts+0.0065453*Ts)*35.0**0.5&
		  -0.17755*35.0+0.0094979*35.0**(1.5)
	deltaV=-65.28 +0.397*t-0.005155*t**2.0+(19.816-0.0441*t-0.00017*t**2.0)
	deltaK=0.01847+0.0001956*t-0.000002212*t**2.0+(-0.03217-0.0000711*t+0.000002212)
	lnKP=lnKKca-deltaV/(R*Ts)*p+0.5*deltaK/(R*Ts)*p**2.0
	KKca=exp(lnKP)*1.0d12
return 
end

!_____Solubility product of aragonite (mmol m-3)^2 (Mucci, 1983 and Millero, 1983)
real function KKara(t,h)
	implicit none
	
	real*8 t, Ts, logKKara, R, p, deltaV, deltaK, lnKP, rho, g, h

	rho=1025.0
	g=9.82
	Ts=273.15+t

	
	logKKara=-171.945+2903.293/Ts+71.595*log10(Ts)-0.077993*Ts+(-0.068393+88.135/Ts+0.0017276*Ts)*35.0**0.5&
		     -0.10018*35.0+0.0059415*35.0**(1.5)
	KKara=10.0**(logKKara)*1.0d12
return 
end



!_____Find min
real function min(a,b)
	implicit none
	
	real*8 a,b
	
	if(a.lt.b)then
		min=a
	else
		min=b
	endif
	
return 
end