!	*****************************
      module globals
!	*****************************
!	declaration of global variables and definition of parameters
!	last modified:

      implicit none
	  
!	  model setup
!	*****************************      
	  integer, parameter :: tmax=50000!100000		! max. number of timesteps
	  real,    parameter :: delt=0.1		! time step [yr]
	  integer, parameter :: tsave=5000!10000		! saved timestep
	  integer, parameter :: rbio=10		    ! number of dt_oceanbio per dt_oceanphys
	  integer, parameter :: rsed=100		! number of dt_sed per dt_oceanphys
	  integer, parameter :: nmax=335		! max. number of layers in stratified interior ocean
	  integer, parameter :: nsed=100		! max. number of gridpoints in the sediment column
	  integer, parameter :: spmax=15		! max. number of biogeochemical species
	  integer, parameter :: casmax=3		! max. number of carbon species
	  integer, parameter :: nbox=6			! max. number of ocean boxes
	  integer, parameter :: nreac=15		! max. number of reactions
	  
	  real*8 delxi(nmax)					! grid points [distance to the surface in m]
	  real*8 dxa(nmax)						! grid space between delxi(i+1) and delxi(i-1)
	  real*8 dxp(nmax)						! grid space between delxi(i+1) and delxi(i)
	  real*8 dxm(nmax)						! grid space between delxi(i) and delxi(i-1)
	  
	  real*8 delxi_sed(nsed)				! grid points [distance to the SWI in m]
	  real*8 dxa_sed(nsed)					! grid space between delxi_sed(i+1) and delxi_sed(i-1)
	  real*8 dxp_sed(nsed)					! grid space between delxi_sed(i+1) and delxi_sed(i)
	  real*8 dxm_sed(nsed)					! grid space between delxi_sed(i) and delxi_sed(i-1)

!	biogeochemistry
	 type species                       ! Define new type 'species', which is characterized by
		character(len=10) :: name		! name
		integer state                   ! solid (1) or dissolved state (0)
		real*8 gex						! advective velocity: dissolve=wi, solid=set
		real*8 cps						! concentration in the surface layer of the well-mixed, deep, polar ocean
		real*8 cpd						! concentration in the well-mixed, deep, polar ocean
		real*8 ccd						! concentration in the deep, coastal ocean
		real*8 cis						! concentration in the surface layer of the interior ocean
		real*8 ccs						! concentration in the surface layer of the coastal ocean
		real*8 cid(nmax)                ! concentration array in the stratified interior ocean
		real*8 atm(nbox)				! concentration in the atmosphere above the coastal ocean
		real*8 sol(nbox)				! saturation concentration of gases in seawater
		real*8 csed_cd(nsed)			! concentration array in the sediment column below the deep coastal ocean 
		real*8 csed_id(nsed)			! concentration array in the sediment column below the deep interior ocean 
		real*8 csed_pd(nsed)			! concentration array in the sediment column below the deep polar ocean 
		real*8 diff(nsed)				! dispersion coefficient in the sediment [m2 yr-1]
	 end type species
	 
!	carbonate system
	 type carbsys						! Define new type 'carbsys', which is characterized by
		character(len=10) :: name		! name
		real*8 cps						! concentration in the surface layer of the well-mixed, deep, polar ocean
		real*8 cpd						! concentration in the well-mixed, deep, polar ocean
		real*8 ccd						! concentration in the deep, coastal ocean
		real*8 cis						! concentration in the surface layer of the interior ocean
		real*8 ccs						! concentration in the surface layer of the coastal ocean
		real*8 cid(nmax)                ! concentration array in the stratified interior ocean
		real*8 csed_cd(nsed)			! concentration array in the sediment column below the deep coastal ocean 
		real*8 csed_id(nsed)			! concentration array in the sediment column below the deep interior ocean 
		real*8 csed_pd(nsed)			! concentration array in the sediment column below the deep polar ocean 
	 end type carbsys
	 
	 type(species) sp(spmax)			! Declare array of type 'species'
	 type(carbsys) cas(casmax)			! Declare array of type 'carbsys'

	 real*8 tb							! species with constant concentration
	 real*8 ca
	 
	 integer, parameter :: poc=1, tem=2, o2=3, no3=4, nh4=5, po4=6, so4=7, ch4=8
	 integer, parameter :: ts=9, tc=10, ta=11, h=12, caco3=13, clight=14, cheavy=15
	 
	 integer, parameter :: sh2co3=1, shco3=2, sco3=3
	 integer, parameter :: cs=1, cd=2, is=3, id=4, ps=5, pd=6

!	  atmosphere
!	*****************************
	  real*8	factor_co2		!factor pp=x*PAL
	  real*8    factor_o2
	  real*8	mass_o2			!mass o2 [mmol]
	  real*8	mass_co2
	  real*8	PALo2			!partial pressure o2 eq. to 1PAL
	  real*8	PALco2
	  real*8	mass_o2PAL		!mass o2 eq. to 1PAL
	  real*8	mass_co2PAL
	  real*8    fairseaco2
	  real*8	fairseao2

	  
!	 continent: weathering fluxes and isotope ratios
!	*****************************
	  real*8	fsilw					! silicate weathering	[mmol/ yr]
	  real*8	fbasw					! basalt weathering		[mmol/ yr]
	  real*8	fcarbw					! carbonate weathering	[mmol/ yr]
	  real*8	fkerw					! kerogene weathering	[mmol/ yr]	
	  real*8    fpw						! phosphate weathering  [mmol/ yr]
	  real*8	fnitro					! nitrogen weathering   [mmol/ yr]


!	 continent/ocean: volcanic and hydrothermal fluxes
!	*****************************	  
	  real*8	fvoltc					! volcanic CO2 input [mmol/yr]
	  real*8	fmortc					! mid-oceanic ridge DIC flux [mmol/yr]
	  real*8	fmorta					! mid-oceanic ridge TA  flux [mmol/yr]
	  real*8	fmorch4					! mid-oceanic ridge CH4 flux [mmol/yr]
	  real*8	fmorh2s					! mid-oceanic ridge H2S flux [mmol/yr]


!	  ocean: geometry
!	*****************************	  
	  integer, parameter :: D_tc=50		! depth of surface ocean [m]
	  integer, parameter :: D_do=3350	! depth of deep ocean [m]; check grid spacing!!
	  integer, parameter :: D_co=100	! depth of the coastal ocean  [m]
	  integer, parameter :: D_up=100    ! max upwelling depth [m] note: D_up=upwelling depth-D_tc
	  
	  real, parameter :: Ac=0.04E15		! surface area coastal ocean [m2]
	  real, parameter :: Ai= 0.2817E15	! surface area interior ocean [m2]
	  real, parameter :: Ap=0.07707E15	! surface area polar ocean [m2]
	  real, parameter :: Areef=0.04E15	! surface area shallow water precipitation [m2]
	  
	  real*8 wdepth(nbox)				! average waterdepth of ocen boxes [m]


!	  ocean: transport parameters
!	*****************************
	  real*8 wi 						! upwelling interior ocean [m/yr]
	  real*8 q							! bilateral exchange between interior and polar ocean [1/yr]
	  real*8 cq							! bilateral exchange between interior and coastal ocean [1/yr]
      real*8 hex						! bilateral exchange bewteen the polar surface ocean and deep ocean [m/yr]
	  real*8 chex						! bilateral exchange bewteen the coastal surface ocean and deep ocean [m/yr]
	  real*8 up							! coastal upwelling [m/yr]
	  real*8 disp(nmax)					! turbulent dispersion [m2/yr]
	  real*8 iup(nmax)					! upwelling field for interior ocean [m/yr]
	  real*8 iq(nmax)					! bilateral exchange between interior and coastal ocean [1/yr]
	  real*8 gex						! exchange with the atmosphere [m/yr]
	  real*8 set_poc					! POC sinking rate [m/yr]
	  real*8 sumT(nbox, spmax)			! concentration change due to transport processes [mmol m-3 yr-1]
	  real*8 dsumT(nmax, spmax)			! concentration change due to transport processes [mmol m-3 yr-1]
	  
!	  sediment: transport parameters
!	*****************************
	  real*8 omega(nbox)				! sedimentation velocity m/yr
	  real*8 Db(nbox)					! bioturbation coefficient m2/yr
	  real*8 Fsed(spmax,nbox)			! diffusive flux [mmol m-2 yr-1]
	  real*8 por_d(nsed)				! porosity
	  real*8 por_0						! porosity at the SWI
	  real*8 por_n						! porosity at nmax
	  real*8 attpor						! exponential factor
	  real*8 sd(nsed)					! conversion factor solid->dissolved

!	  ocean biogeochemistry: rate constants
!	*****************************

	  real*8 nc							!N/C ratio organic matter
	  real*8 pc							!P/C ratio organic matter
	  real*8 nc_sed						!N/C ratio organic matter
	  real*8 pc_sed						!P/C ratio organic matter
	  real*8 mu1						!maximum rate of export production [1/yr]
	  real*8 mu2						!maximum rate of export production/ nitrogen fixers [1/yr]
	  real*8 a							!parameter RCM [yr] 
	  real*8 nu							!parameter RCM [-]
	  real*8 nu_po						!parameter RCM [-]
	  real*8 knit						!maximum rate of nitrification [m3 mmol-1 yr-1]
	  real*8 kmreox						!maximum rate of methane reoxidation [m3 mmol-1 yr-1]
	  real*8 ksreox						!maximum rate of sulfide reoxidation [m3 mmol-1 yr-1]
	  real*8 kaom						!maximum rate of anaerobic methane oxidation [m3 mmol-1 yr-1]
	  real*8 kmo2						![mmol/m3] half saturation concentration SO4
	  real*8 kmno3						![mmol/m3] half saturation concentration NO3
	  real*8 kmso4						![mmol/m3] half saturation concentration SO4
	  real*8 kpyr                       !pyrite formation
	  real*8 h2s_0                      !half saturation concentration
	  real*8 rpicpoc 					!caco3-poc export flux ratio [-]
	  real*8 rpicpoc_po
	  real*8 coeffta(nreac)				!stoichiometric coefficients total alkalinity
	  real*8 coefftc(nreac)				!stoichiometric coefficients total dissolved inorganic carbon
	  real*8 coeffts(nreac)             !stoichiometric coefficients total dissolved sulfides
	  real*8 kcaco3						!CaCO3 precipitation/dissolution [yr-1]
	  real*8 nca
	  real*8 kreef						!reef production [mmol m-2 yr-1]
	  real*8 KO2redox					!MM constant secondary redox reactions [mmol m-3]
	  real*8 KSO4redox					!MM constant secondary redox reactions [mmol m-3]

!	  sediment biogeochemistry: rate constants
!	*****************************

	  real*8 nu_sed					    ! parameter RC model
	  real*8 a_sed					    ! parameter RC model	
	  real*8 kmo2_sed					! half saturation concentration O2
	  real*8 kmno3_sed					! half saturation concentration NO3
	  real*8 kmso4_sed					! half saturation concentration SO4
	  real*8 knit_sed					! rate constant nh4 oxidation
	  real*8 kaom_sed					! rate constant ch4 oxidation by so4
	  real*8 kmreox_sed 			    ! rate constant ch4 oxidation by o2
	  real*8 ksreox_sed                 ! rate constant ts oxidation by o2
	  real*8 adpo4_ox					! adsorption coefficient of po4 on fe(oh)3 under oxic conditions
	  real*8 adpo4_anox					! adsorption coefficient of po4 on fe(oh)3 under anoxic conditions
	  real*8 adnh4						! adsorption coefficient of nh4
	  real*8 kapa						! precipitation constant for apatite
	  real*8 po4_eq						! equilibrium concentration for apatite precipitation


		
end module globals
	  
	  