!	*****************************
	subroutine transport_sed(co, bc, phase, vx, s, box)
!	*****************************
!   calculate dC/dt|trans
!	last modified:

	use globals
    implicit none

	real*8 di(nsed),aa(nsed),c(nsed),bb(nsed),rr(nsed),co(nsed),gam(nsed),cold(nsed),fl(nsed), diff(nsed), por(nsed)
	real*8 bet, dtdxp, dtdxa,  dtdxm, c1, c2, bc, vx, erfcc
	real*8 cfl, f, philen, rg, vel_t, cb, vterm, delt_sed
	integer n, j, i, nsp, t, phase, s, box
	
	delt_sed=delt/rsed

!___set diffusion coefficient	
!___set apparent diffusion coefficient for po4, depending on redox zonation of the sediment
do i=1,nsed
	diff(i)=sp(s)%diff(i)+Db(box)/2.0*erfcc((delxi_sed(i)*100.0-10.0)/4.0)
enddo



if(s.eq.po4)then
	select case (box)
			case (2)
			do i=1,nsed
				if(sp(no3)%csed_cd(i).lt.0.0)then
					diff(i)=1.0/(adpo4_anox+1.0)*diff(i)
				else
					diff(i)=1.0/(adpo4_ox+1.0)*diff(i)
				endif
			enddo
			case (4)
			do i=1,nsed
				if(sp(no3)%csed_id(i).lt.0.0)then
					diff(i)=1.0/(adpo4_anox+1.0)*diff(i)
				else
					diff(i)=1.0/(adpo4_ox+1.0)*diff(i)
				endif
			enddo
			case (6)
			do i=1,nsed
				if(sp(no3)%csed_pd(i).lt.0.0)then
					diff(i)=1.0/(adpo4_anox+1.0)*diff(i)
				else
					diff(i)=1.0/(adpo4_ox+1.0)*diff(i)
				endif
			enddo		
	 end select
endif

!___define phase-dependent stuff___	

!___dissolved species______________
	if(phase.eq.0 .OR. phase.eq.2) then
		do i=1,nsed
			por(i)=por_d(i)
		enddo
		
		! upper boundary condition: fixed concentration
		aa(1) = 0.0
		c(1)  = 0.0
		bb(1) = 1.0
		di(1) = bc ! conc. SWI
		
		! lower boundary condition: no diff flux condition
		aa(nsed) = 1.0
		c(nsed)  = 0.0    
		bb(nsed) = -1.0     
		di(nsed) = 0.0
		
!___solid species______________	
	else
		do i=1,nsed
			por(i)=1.0-por_d(i)
		enddo
		! upper boundary condition: flux condition
		! only advection
		if(diff(1).eq.0.0)then 
			aa(1) = 0.0
			c(1)  = 0.0
			bb(1) = 1.0
			di(1) = bc/(por(1)*vx) ! conc. SWI, bc is given in mmol/(m2 yr)
					
		! advection+dispersion
		else
			vel_t=vx*por(1)
			cb=(diff(1)*por(1)+diff(2)*por(2))/2.d0
			vterm=vel_t*delt_sed/dxa_sed(1)-vel_t*vel_t*delt_sed/(2.d0*cb)
			aa(1) = 0.d0
			c(1)  = -cb*delt_sed/(dxa_sed(1)*dxa_sed(1))
			bb(1) = 1.d0*por(1)+cb*delt_sed/(dxa_sed(1)*dxa_sed(1))+vterm 
			rr(1) = 1.d0*por(1)-cb*delt_sed/(dxa_sed(1)*dxa_sed(1))-vterm
			di(1) = rr(1)*co(1)-c(1)*co(2)+bc*(2.d0*delt_sed/dxa_sed(1)-vel_t*delt_sed/cb) ! bc=deposition flux
		end if
		! lower boundary condition: no disp flux condition
	    aa(nsed) = 1.0
		c(nsed)  = 0.0
		bb(nsed) = -1.0
		di(nsed) = 0.d0
	endif
	
!	**************************************************************************	
!___disersive term___________________________________________________________
! disersion coefficient depth-dependent, disersion coefficients taken at 1/2 grid points, e.g. Boudreau, 1998 p.330
! boundary conditions only applied to disersive term and c(0), c(nsed) taken as bc for TVD scheme
		  
!----coeff of tridiag. matrix
	do i=2,nsed-1
		dtdxp = delt_sed/(2.d0*dxp_sed(i)*dxa_sed(i)) ! see Boudreau 1998 for discretization on uneven grids, =(delxi_sed(i+1)-delxi_sed(i))*((delxi_sed(i+1)-delxi_sed(i))+(delxi_sed(i)-delxi_sed(i-1)))
	    dtdxm = delt_sed/(2.d0*dxm_sed(i)*dxa_sed(i))
		c1    = (diff(i-1)*por(i-1)+diff(i)*por(i))/2.d0
		c2    = (diff(i+1)*por(i+1)+diff(i)*por(i))/2.d0
		
		aa(I) = -c1*dtdxm
		c(I)  = -c2*dtdxp
		bb(I) = 1.d0*por(i)+c2*dtdxp+c1*dtdxm
		rr(I) = 1.d0*por(i)-c2*dtdxp-c1*dtdxm
		di(i) = -c(i)*co(i+1)+rr(i)*co(i)-aa(i)*co(i-1)	 
	end do
 
!___solve tridiagonal matrix
	if(bb(1).eq.0.)pause 'tridag: rewrite equations'
	bet=bb(1)
	co(1)=di(1)/bet
	do j=2,nsed
		gam(j)=c(j-1)/bet
		bet=bb(j)-aa(j)*gam(j)
		if(bet.eq.0.)pause 'tridag failed'
		co(j)=(di(j)-aa(j)*co(j-1))/bet
	end do

	do j=nsed-1,1,-1
		co(j)=co(j)-gam(j+1)*co(j+1)
	end do

!	**************************************************************************	
!___advective terms___________________________________________________________
! note that upper boundary condition(disp+adv) is only applied to the dispersion scheme, i.e. co(1) not modified in advection scheme 

	do j=1,nsed
		cold(j)=co(j)
	enddo
	
!---calculate flux at i=1
	dtdxa = delt_sed/(dxa_sed(1))
	dtdxp = delt_sed/(dxp_sed(1))
	cfl = abs(vx*dtdxp)
	
	if (vx.gt.0.0) then
		f = cold(2)-cold(1)
		rg = 0.d0
		philen = max(0.d0,min(2.d0,2.d0*rg,(2.d0-cfl+rg*(1.d0+cfl))/3.d0))
		fl(1) = vx*por(1)*(cold(1)+0.5*(1.0-cfl)*philen*f)
	else
		f = cold(1)-cold(2)
		rg = 0.d0
		philen = max(0.d0,min(2.d0,2.d0*rg,(2.d0-cfl+rg*(1.d0+cfl))/3.d0))
		fl(1)  = vx*por(1)*(cold(2)+0.5*(1.0-cfl)*philen*f)
	endif

!---TVD scheme with flux limiter for inner grid points- boundary concentrations c(0) calculated in dis step
	do i = 2,nsed
		dtdxa = delt_sed/(dxa_sed(i))
		dtdxp = delt_sed/(dxp_sed(i))
		cfl = abs(vx*dtdxp)
		
		if (vx.gt.0.0) then
			f = cold(i+1)-cold(i)
			if (dabs(f).gt.1.e-35) then
				rg = (cold(i)-cold(i-1))/f
				philen = max(0.d0,min(2.d0,2.d0*rg,(2.d0-cfl+rg*(1.d0+cfl))/3.d0))
			else
				philen = 0.0
			endif
			fl(i) = vx*por(i)* (cold(i) + 0.5*(1.0-cfl)*philen*f)
			co(i) = cold(i)-(dtdxa/por(i))*(fl(i)-fl(i-1))
		endif
		
		if (vx.lt.0.0) then
			f = cold(i)-cold(i+1)
			if (dabs(f).gt.1.e-35) then
				if (i.eq.nsed-1) then
					rg=0.d0
				else
					rg = (cold(i+1)-cold(i+2))/f
				endif
				philen = max(0.d0,min(2.d0,2.d0*rg,(2.d0-cfl+rg*(1.d0+cfl))/3.d0))
			else
				philen = 0.0
			endif
			fl(i) = vx*por(i)*(cold(i+1)+0.5*(1.0-cfl)*philen*f)
			co(i) = cold(i)-(dtdxa/por(i))*(fl(i)-fl(i-1))
		endif
	end do
		return
	end 



	  