	subroutine weathering(fsilw,fbasw,fcarbw,fkerw,fpw,fnitro,factor_co2)
!   ---------------------------------------------------------

	implicit double precision (a-h,o-z)
	include 'weathering.inc'

	
	
	temgl=0.
	PCO2=factor_co2
	
	do j=1,npixel
	      do i=1,nFOAM
		Tinterd(i)=TairFOAM(j,i)
	      end do
	        p=PCO2
	      if (p.ge.co2FOAM(1).and.p.le.co2FOAM(nFOAM)) then
		 call interd(p,TFOAM(j),co2FOAM,Tinterd,nFOAM,k1,k2)
	      endif
	      if (p.gt.co2FOAM(nFOAM)) then
	         TFOAM(j)=Tinterd(nFOAM)
	      endif 
	      if (p.lt.co2FOAM(1)) then
	         TFOAM(j)=Tinterd(1)
	      endif 
	end do

	do j=1,npixel
		temgl=temgl+(TFOAM(j))*areaFOAM(j)/areatot
	end do
	temgl=temgl+273.15




!	initialising:
	fsilw=0.
	fbasw=0.
	fcarbw=0.
	fkerw=0.
	fpw=0.
	ftrapw=0.
	fnitro=0.


	Rgas=8.314

	do j=1,npixel
!	===================== 
!	Granitic weathering  !from Oliva et al 2003
!	=====================
	   facgra=(-48200./Rgas)*(1./(TFOAM(j)+273.15)-1./288.15)

	   fsil(j)=0.84763104d+9*dexp(facgra)*runclim(j)*areaFOAM(j)
	   fsilw=fsilw+fsil(j)

!	===================== 
!	Basaltic weathering  !from Dessert et al. 2003
!	=====================
	   facbas=(-42300./Rgas)*(1./(TFOAM(j)+273.15)-1./288.15)
	   fbas(j)=0.036678566d+10*dexp(facbas)*runclim(j)*areaFOAM(j)
	   fbasw=fbasw+fbas(j)

!	===================== 
!	Carbonate weathering !from GEOCLIM et al. 20XX
!	=====================
	if (areaFOAM(j).ne.0) then
	     call carbo(TFOAM(j),runclim(j),carb_weath_conc,j)  !calculates the Ca concentration at steady-state with pCO2 and calcite
	endif
	   fcarb(j)=0.430722644993d+10*runclim(j)*areaFOAM(j)&  !full newton
                  *carb_weath_conc  !before 0.27620099d+10
	   fcarbw=fcarbw+fcarb(j)

!	===================== 
!	Kerogen weathering
!	=====================
	   facker=(-43000./Rgas)*(1./(TFOAM(j)+273.15)-1./288.15) !temperature dependence from X and Berner, not used but...
	   fker(j)=1.770*0.04930703176514192d+10*runclim(j)*areaFOAM(j)
!     &             *dexp(facker)  !0.672d+10
	   fkerw=fkerw+fker(j)
!	   fkerw=4.606d+12
!	===================== 
!	Phosphorus weathering   !from Guidry et al. 2000, 2003
!	=====================
	   fp(j)=2744.14942196567d+10*areaFOAM(j)*runclim(j)&
                 *dexp(-34777/(8.314*(TFOAM(j)+273.15)))*&
                 (0.0025*pco2soil**0.435)**0.27&        !power fit
                 +0.07941586830069897d+10*&
                 (1./250.*runclim(j)*areaFOAM(j)&
                +1./1000.*runclim(j)*areaFOAM(j)&
                  *carb_weath_conc)
	   fpw=fpw+fp(j)
	   
!   ====================
!   Nitrogen weathering  !from Berner 2006, just believe !
!   ====================
	  fn(j)=0.03*fker(j)+0.001*(fbas(j)+fsil(j))
	  fnitro=fnitro+fn(j)
	end do
	
	  fsilw=fsilw*1000.0	! mol/yr->mmol/yr modified:sa 20/03/2010 
	  fbasw=fbasw*1000.0
	  fcarbw=fcarbw*1000.0*0.5
	  fkerw=fkerw*1000.0
      fpw=15.0*fpw*1000.0
	  fnitro=fnitro*1000.0
	
	return
	end



	subroutine runoff_cal(factor_co2)
!   --------------------
	implicit double precision (a-h,o-z)
	parameter (nv=180)
	include 'weathering.inc'


	runoff_tot=0.
	PCO2=factor_co2

	do j=1,npixel
	  do i=1,nFOAM
	    Runinterd(i)=RunFOAM(j,i)
	  end do
	  p=PCO2
	  if (p.ge.co2FOAM(1).and.p.le.co2FOAM(nFOAM)) then
	   call interd(p,runclim(j),co2FOAM,Runinterd,nFOAM,k1,k2)
	  endif
	  if (p.gt.co2FOAM(nFOAM)) then
	   runclim(j)=Runinterd(nFOAM)
	  endif
	  if (p.lt.co2FOAM(1)) then
	   runclim(j)=Runinterd(1)
	  endif
	  runoff_tot=runoff_tot+runclim(j)*areaFOAM(j)/areatot
	  if (runclim(j).lt.0) runclim(j)=0.
	end do
	

	return
	end

      SUBROUTINE INTERD(T,X,TDAT,XDAT,NN,K1,K2)
!     -----------------------------------------
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION TDAT(0:NN),XDAT(0:NN)
      DO 200 K=1,NN-1
       IF(T.LE.TDAT(K))THEN
         K2=K
         GO TO 210
       ENDIF
 200  CONTINUE
      K2=NN
 210  CONTINUE
      K1=K2-1
      X=XDAT(K1)+(XDAT(K2)-XDAT(K1))*(T-TDAT(K1))/(TDAT(K2)-TDAT(K1))
      RETURN
      END


	subroutine carbo(temperature,runoff,xmass_carbonate,j)
!   =============================================
	implicit double precision (a-h,o-z)

	include 'weathering.inc'

	Pmax=1.+0.302483*runoff**0.8
	Patm=PCO2
	pco2soil=Patm+Pmax/(1+dexp(1.315-0.119*(temperature)))
	
	temper=temperature+273.15
	
	x1=1.d-7
	x2=1.d-1
	xacc=1.d-10
	 xn=1.d-4

	call newton(xn,fx,dfx,xacc,temper)
	
!	write(*,*)-dlog10(xn*1d-3),runoff,j
	
	out=xn

	h2co3soil=betasoil*pco2soil
	hco3soil=ak1soil*h2co3soil/out
	co3soil=hco3soil*ak2soil/out
	Calcium=0.5*(hco3soil+2*co3soil)  !mol/m3 before: 1. 0.5
	xmass_carbonate=Calcium !mol/m3
	
	return
	end



      subroutine newton(x,fx,dfx,ermaxa,temper)
!     ----------------------------------
      implicit double precision (a-h,o-z)
!
!     methode de newton-raphson amelioree

	eror=1.d-10
!
	call phfunc(x,fx0,dfx,temper)
      fx=fx0

      num=1
!
!     commencer par des pas doubles jusqu'a ce que fx*fx0<0
!
 1    continue
      x=x-2.*fx/dfx
	call phfunc(x,fx,dfx,temper)
      num=num+1
      fxfx0=fx*fx0
      if(num.ge.51)then
        write(74,*)'num=',num,' x=',x
        write(74,*)'fx=',fx,' dfx=',dfx
        write(74,*)'program stop'
        stop
      endif
      if(fxfx0.gt.0.)go to 1
!
!     continuer par newton-raphson classique
!
 2    continue
      residu=-fx/dfx
      x=x+residu
      call phfunc(x,fx,dfx,temper)
      num=num+1
      err=dabs(residu/x)
      if(num.ge.101)then
        write(74,*)'num=',num,' x=',x
        write(74,*)'fx=',fx,' dfx=',dfx
        write(74,*)'program stop'
        stop
      endif
      if(err.gt.eror)go to 2
!
      return
      end
	  
	  
	subroutine phfunc(xo,fsoil,dfsoil,temper)
!     ----------------------
!	This routine calculate pH for a solution at equilibrium with
!	soil PCO2 and carbonate rock. Used to estimate carbonate weathering

	implicit double precision (a-h,o-z)

	include 'weathering.inc'


	salsoil=0.
	prsoil=0.
	
	call eqcte(temper,salsoil,prsoil,betasoil,ak1soil,ak2soil,akbsoil,akcsoil)
	 

	aksp=-0.38031396+0.0037566543*temper&
            -1.2063922d-5*temper*temper&
            +1.2696055d-8*temper*temper*temper
	if (temper.lt.278.15) then
	    aksp=0.004460795   !to maintain aksp constant below 278.15 K
	endif 

	Hsoil=xo

	fsoil=2.*aksp*xo*xo*xo*xo/(ak1soil*ak2soil*betasoil*pco2soil)&  !before 1  2
                     -ak1soil*betasoil*pco2soil*xo&
                     -2*ak1soil*ak2soil*betasoil*pco2soil
	dfsoil=2.*4*aksp*xo*xo*xo/(ak1soil*ak2soil*betasoil*pco2soil)-& !before 1  2
          ak1soil*betasoil*pco2soil

	return
	end



      SUBROUTINE EQCTE(TEM,SAL,PR,BC,AK1,AK2,AKB,AKC)
!     -----------------------------------------------
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
!     THIS SUBROUTINE RETURNS THE EQUILIBRIUM CONSTANTS IN MOL/M3
!     FOR THE DISSOCIATION OF H2CO3 (AK1), HCO3 (AK2) AND H3BO3 (AKB)
!     AS A FUNCTION OF TEMPERATURE (TEM) IN KELVIN, SALINITY (SAL)
!     IN PER MIL AND PRESSURE (PR) IN BAR. IT ALSO RETURNS
!     HENRYS LAW CONSTANT BC FOR CO2, IN MOL/M3/PAL, AND THE
!     SATURATION PRODUCT (AKC) FOR CALCITE AT PR=0 IN MOL/M3*MOL/M3.
      AK0=-58.0931+9050.69/TEM+22.2940*DLOG(TEM/100.)&
         +SAL*(0.027766-0.025888*TEM/100.+0.0050578*TEM*TEM/10000.)
      AK0=DEXP(AK0)*1.E+3
      BC=280.E-6*AK0
      AK1=290.9097-14554.21/TEM-45.0575*DLOG(TEM)&
         +DSQRT(SAL)*(0.0221+34.02/TEM)
      AK1=DEXP(AK1)*1.E+3
      AK2=207.6548-11843.79/TEM-33.6485*DLOG(TEM)&
         +DSQRT(SAL)*(0.9805-92.65/TEM)-0.03294*SAL
      AK2=DEXP(AK2)*1.E+3
      AKB=148.0248-8966.90/TEM-24.4344*DLOG(TEM)&
         +DSQRT(SAL)*(0.5998-75.25/TEM)-0.01767*SAL
      AKB=DEXP(AKB)*1.E+3
      AKC=303.1308-13348.09/TEM-48.7537*DLOG(TEM)&
         +DSQRT(SAL)*(1.6233-118.64/TEM)-0.06999*SAL
      AKC=DEXP(AKC)*1.E+6
      IF(PR.GE.1.)THEN
       PRATM=PR/1.013
       TCEL=TEM-273.15
       RT=82.056*TEM
       DV1=-(25.50+0.151*(SAL-34.8)-0.1271*TCEL)
       DK1=-1.e-3*(3.08+0.578*(SAL-34.8)-0.0877*TCEL)
       ARG=-DV1*PRATM/RT+0.5*DK1*PRATM*PRATM/RT
       AK1=AK1*DEXP(ARG)
       DV2=-(15.82-0.321*(SAL-34.8)+0.0219*TCEL)
       DK2=-1.e-3*(-1.13+0.314*(SAL-34.8)+0.1475*TCEL)
       ARG=-DV2*PRATM/RT+0.5*DK2*PRATM*PRATM/RT
       AK2=AK2*DEXP(ARG)
       DVB=-(29.48-0.295*(SAL-34.8)-0.1622*TCEL+0.002608*TCEL*TCEL)
       DKB=-1.e-3*(2.84-0.354*(SAL-34.8))
       ARG=-DVB*PRATM/RT+0.5*DKB*PRATM*PRATM/RT
       AKB=AKB*DEXP(ARG)
      ENDIF
      RETURN
      END